<?PHP
/**
 * Represents a possible target for importing related works
 * as defined by LIDO.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Represents a possible target for importing related works
 * as defined by LIDO.
 */
enum MDConcFieldRelatedWorksType {

    case related_works_freetext;
    case series;
    case literature;
    case weblink;
    case undefined;

    /**
     * Returns a target field value of this type based on a string.
     *
     * @param string $input Input to get a value from.
     *
     * @return MDConcFieldRelatedWorksType
     */
    public static function fromString(string $input):MDConcFieldRelatedWorksType {

        return match($input) {

            "Dokumentiert in",
            "dokumentiert in",
            "Erwähnung in",
            ":iterature",
            "Beschrieben in",
            "Literatur",
            "Literatur in Zusammenhang",
            "beschrieben in" => self::literature,

            "Teil von",
            "ist Teil von",
            "Gehört zu",
            "Part of",
            "Gesamtwerk",
            "part of",
            "Photoserie",
            "Mappe",
            "series",
            "Serie" => self::series,

            "hat Vorlage",
            "Kopie von",
            "Objekt",
            "ist Version von",
            "inhaltlicher Bezug zu",
            "Teil",
            "has part",
            "Dublette",
            "Objektbezug",
            "Vergleiche",
            "Umfasst",
            "Entwurf",
            "Vorderseite",
            "Rückseite",
            "Paarweise mit",
            "Zustandsdruck",
            "Foto",
            "Original",
            "Variante",
            "Aufnahme Objekt",
            "Zusammen mit",
            "Ausführung",
            "Related objects",
            "Join",
            "Hauptobjekt",
            "Akte",
            "Vorgang",
            "Form",
            "Identisch mit",
            "Kopie",
            "Gegenstück zu",
            "hat Version",
            "hat Kopie",
            "ist Verso von",
            "ist Recto von",
            "ist Kopie nach",
            "ist Quelle für",
            "in Beziehung zu",
            "ist abgeleitet von",
            "ist vorbereitend für",
            "Enthalten in",
            "Enthält",
            "Verso von",
            "Recto von",
            "ist Teil desselben konzeptuellen Ganzen mit",
            "ist vorbereitende Studie für",
            "Druck",
            "Referenz",
            "Haupttafel",
            "Faksimile",
            "Blatt",
            "Photo",
            "Einzelteil",
            "Vorlage" => self::related_works_freetext,

            "Weblink",
            "Web link" => self::weblink,

            "" => self::undefined,

            default => throw new MDpageParameterNotFromListException("Unknown target field for related works type: " . $input),
        };

    }
}
